<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl_PL">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="watchvideo/ui_about.py" line="63"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_about.py" line="64"/>
        <source>Credits</source>
        <translation>Zasługi</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_about.py" line="65"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_about.py" line="66"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="src/about.py" line="48"/>
        <source>WatchVideo is a small application to play or download videos from various youtube-like sites.
It&apos;s made in PyQt4.</source>
        <translation type="obsolete">WatchVideo jest małym programem pobierającym lub odtwarzającym filmy ze stron takich jak YouTube.
Korzysta z PyQt4.</translation>
    </message>
    <message>
        <location filename="watchvideo/about.py" line="44"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="watchvideo/about.py" line="48"/>
        <source>WatchVideo is a small application to play, download or convert videos (to Ogg) from various youtube-like sites.
It&apos;s made in PyQt4.</source>
        <translation type="obsolete">WatchVideo jest małym programem pobierającym, odtwarzającym i konwertującym do Ogg filmy ze stron takich jak YouTube.
Korzysta z PyQt4.</translation>
    </message>
    <message>
        <location filename="watchvideo/about.py" line="37"/>
        <source>

WatchVideo is a small application to play, download or convert videos (to Ogg) from various youtube-like sites.
It&apos;s made in PyQt4.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddVideos</name>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="167"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="169"/>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="170"/>
        <source>Destination Folder:</source>
        <translation>Katalog docelowy:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="171"/>
        <source>Choose Folder</source>
        <translation>Wybierz katalog</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="173"/>
        <source>After Download:</source>
        <translation>Po pobraniu:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="174"/>
        <source>Do Nothing</source>
        <translation>Nic nie rób</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="175"/>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="176"/>
        <source>Convert to Ogg/Vorbis (audio)</source>
        <translation>Skonwertuj do Ogg Vorbis (dźwięk)</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="177"/>
        <source>Convert to Ogg/Theora (video)</source>
        <translation>Skonwertuj do Ogg Theora (film)</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="178"/>
        <source>Rip Audio</source>
        <translation>Pobierz dźwięk</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="161"/>
        <source>Add Videos</source>
        <translation>Dodaj filmy</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="162"/>
        <source>Paste link(s) here:</source>
        <translation>Wklej linki tutaj:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="136"/>
        <source>Check Links</source>
        <translation type="obsolete">Sprawdź linki</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="165"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="166"/>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="168"/>
        <source>Play directly from link(s)</source>
        <translation>Odtwórz bezpośrednio z linków</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="172"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="164"/>
        <source>Get in high quality, if possible.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="watchvideo/ui_add_videos.py" line="163"/>
        <source>Get Videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddVideosDialog</name>
    <message>
        <location filename="watchvideo/add_videos.py" line="41"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="watchvideo/add_videos.py" line="175"/>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <location filename="watchvideo/add_videos.py" line="175"/>
        <source>The given download folder doesn&apos;t exist!</source>
        <translation>Katalog docelowy nie istnieje!</translation>
    </message>
    <message>
        <location filename="watchvideo/add_videos.py" line="191"/>
        <source>Overwrite</source>
        <translation>Nadpisz</translation>
    </message>
    <message>
        <location filename="watchvideo/add_videos.py" line="191"/>
        <source>Do you wish to overwrite this file?</source>
        <translation>Czy nadpisać ten plik?</translation>
    </message>
    <message>
        <location filename="watchvideo/add_videos.py" line="205"/>
        <source>There are no valid links to add!</source>
        <translation>Nie odnaleziono poprawnych linków do dodania!</translation>
    </message>
</context>
<context>
    <name>Gui</name>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="463"/>
        <source>No supported services were found</source>
        <translation>Nie odnaleziono wspieranych usług</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="464"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="466"/>
        <source>Currently checking: </source>
        <translation>Aktualnie sprawdzane:</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="553"/>
        <source>Opening download directory </source>
        <translation>Otwieranie katalogu pobierania</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="553"/>
        <source>with</source>
        <translation>z</translation>
    </message>
    <message>
        <location filename="src/watchvideo_gui.py" line="326"/>
        <source>download</source>
        <translation type="obsolete">pobierz</translation>
    </message>
    <message>
        <location filename="src/watchvideo_gui.py" line="330"/>
        <source>play</source>
        <translation type="obsolete">odtwórz</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="130"/>
        <source>Start</source>
        <translation>Rozpocznij</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="131"/>
        <source>Stop</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="132"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="133"/>
        <source>Remove and delete file</source>
        <translation>Usuń wraz z plikiem</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="134"/>
        <source>Open Folder</source>
        <translation>Otwórz katalog</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="135"/>
        <source>Copy original URL</source>
        <translation>Skopiuj oryginalny URL</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="516"/>
        <source>Download Finished</source>
        <translation>Pobieranie zakończone</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="644"/>
        <source>There are still downloads active, do you really want to quit?
(you won&apos;t be able to continue the downloads after quit)</source>
        <translation type="obsolete">Pliki są nadal pobierane, czy chcesz je przerwać?
(nie zostaną wznowione po ponownym uruchomieniu programu)</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="456"/>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="365"/>
        <source>Ripping audio of</source>
        <translation>Pobieranie dźwięku z</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="366"/>
        <source>Audio Ripped</source>
        <translation>Dźwięk pobrany</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="369"/>
        <source>Converting video:</source>
        <translation>Konwertowanie filmu:</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="370"/>
        <source>Video Converted</source>
        <translation>Film skonwertowany</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="451"/>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="367"/>
        <source>Error ripping audio</source>
        <translation>Błąd pobierania dźwięku</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="371"/>
        <source>Error converting video</source>
        <translation>Błąd konwersji filmu</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="136"/>
        <source>Play local file</source>
        <translation>Odtwórz plik lokalny</translation>
    </message>
    <message>
        <location filename="watchvideo/watchvideo_gui.py" line="649"/>
        <source>There are still some tasks active, do you really want to quit?
(you won&apos;t be able to continue them after quitting)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="watchvideo/ui_main.py" line="168"/>
        <source>WatchVideo</source>
        <translation>WatchVideo</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="169"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="170"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="171"/>
        <source>Progress</source>
        <translation>Postęp</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="172"/>
        <source>Speed</source>
        <translation>Prędkość</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="173"/>
        <source>Time Left</source>
        <translation>Pozostały czas</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="174"/>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="175"/>
        <source>Edit</source>
        <translation>Edycja</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="176"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="177"/>
        <source>toolBar</source>
        <translation>Pasek narzędzi</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="178"/>
        <source>Shortcut to get the links from the clipboard</source>
        <translation>Skrót do wstawienia linków z schowka</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="179"/>
        <source>Add Videos</source>
        <translation>Dodaj filmy</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="180"/>
        <source>Add one or more links to download or play directly in your favorite mediaplayer.</source>
        <translation>Dodaj jeden lub więcej linków do pobrania lub otworzenia w Twoim ulubionym odtwarzaczu.</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="181"/>
        <source>Search Browser</source>
        <translation>Znajdź z przeglądarki</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="182"/>
        <source>Searches open windows and tabs in your browser for flash videos (only Firefox and derivatives are suported)</source>
        <translation>Szuka filmów używających Flash w otwartych oknach i kartach przeglądarki opartej na Firefoksie</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="183"/>
        <source>Clear Completed</source>
        <translation>Czyszczenie zakończone</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="184"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="185"/>
        <source>Preferences</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="186"/>
        <source>Quit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="187"/>
        <source>Clipboard</source>
        <translation>Schowek</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="188"/>
        <source>Fetch link from the clipboard</source>
        <translation>Pobierz linki z schowka</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="189"/>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="190"/>
        <source>Shortcut to play the video(s) from the url(s) on the clipboard</source>
        <translation>Skrót do otworzenia filmów z URL-i w schowku</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="191"/>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_main.py" line="192"/>
        <source>Shortcut to download the video(s) from the url(s) on the clipboard</source>
        <translation>Skrót do pobrania filmów z URL-i w schowku</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="watchvideo/preferences.py" line="183"/>
        <source>Media Player</source>
        <translation>Odtwarzacz</translation>
    </message>
    <message>
        <location filename="watchvideo/preferences.py" line="183"/>
        <source>Given media player is not valid</source>
        <translation>Wybrano nieprawidłowy odtwarzacz</translation>
    </message>
</context>
<context>
    <name>PreferencesWindow</name>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="182"/>
        <source>Preferences</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="184"/>
        <source>Default media player:</source>
        <translation>Domyślny odtwarzacz:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="188"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="182"/>
        <source>Save played or downloaded urls in history</source>
        <translation type="obsolete">Zapamiętaj odtwarzane lub pobrane URL w historii</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="183"/>
        <source>Save permanently (urls will be saved to disk)</source>
        <translation type="obsolete">Zapisz URL-e na dysk</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="186"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="187"/>
        <source>Default download folder:</source>
        <translation>Domyślny katalog pobierania:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="189"/>
        <source>Default action after download:</source>
        <translation>Domyśle działanie po pobraniu:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="190"/>
        <source>Do Nothing</source>
        <translation>Nic nie rób</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="191"/>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="192"/>
        <source>Convert to Ogg/Vorbis (Audio)</source>
        <translation>Skonwertuj do Ogg Vorbis (dźwięk)</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="193"/>
        <source>Convert to Ogg/Theora (Video)</source>
        <translation>Skonwertuj do Ogg Theora (film)</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="194"/>
        <source>Rip Audio</source>
        <translation>Pobierz dźwięk</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="198"/>
        <source>Download Options</source>
        <translation>Opcje pobierania</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="189"/>
        <source>Youtube</source>
        <translation type="obsolete">YouTube</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="209"/>
        <source>High Quality</source>
        <translation type="obsolete">Wysoka jakość</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="210"/>
        <source>Low Quality</source>
        <translation type="obsolete">Niska jakość</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="208"/>
        <source>Blip.tv</source>
        <translation type="obsolete">Blip.tv</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="204"/>
        <source>Video Quality</source>
        <translation>Jakość filmu</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="205"/>
        <source>Notification Messages</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="206"/>
        <source>The download ends successfully.</source>
        <translation>Pobieranie zakończone z powodzeniem.</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="207"/>
        <source>Show a notification message when:</source>
        <translation>Wyświetl powiadomienie gdy:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="194"/>
        <source>The download fails.</source>
        <translation type="obsolete">Pobieranie nie powiodło się.</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="212"/>
        <source>Notifications</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="209"/>
        <source>If you want to use your system&apos;s default way to popup messages you can install &apos;python-notify&apos;. 
In case python-notify isn&apos;t installed, WatchVideo uses baloon tooltips on the tray icon provided by Qt4.</source>
        <translation>Jeżeli chcesz użyć systemowe powiadomienia, zainstaluj pakiet „python-notify”.
Jeżeli nie jest on zainstalowany, to WatchVideo użyje powiadomienia z Qt4.</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="211"/>
        <source>Note:</source>
        <translation>Uwaga:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="195"/>
        <source>When double-clicking a completed download:</source>
        <translation>Przy podwójnym kilknięciu pobranego pliku:</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="196"/>
        <source>Play Local File</source>
        <translation>Odtwórz plik lokalny</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="197"/>
        <source>Open Folder</source>
        <translation>Otwórz katalog</translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="199"/>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="201"/>
        <source>All High Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="202"/>
        <source>All low quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="203"/>
        <source>Mixed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="208"/>
        <source>An error occurs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="watchvideo/ui_preferences.py" line="183"/>
        <source>Use built-in player.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
